@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef SCREENSAVERINHIBITPLUGIN_H
@@ -34,7 +34,7 @@ public:
     explicit ScreensaverInhibitPlugin(QObject* parent, const QVariantList& args);
     ~ScreensaverInhibitPlugin() override;
 
-    bool receivePackage(const NetworkPackage& np) override;
+    bool receivePacket(const NetworkPacket& np) override;
     void connected() override;
 
 private:
